/**
Copyright (c) 2015 The Chromium Authors. All rights reserved.
Use of this source code is governed by a BSD-style license that can be
found in the LICENSE file.
**/

require("../model/user_model/load_expectation.js");

'use strict';

global.tr.exportTo('tr.importer', function() {
  // This global instant event marks the start of a navigation.
  var NAVIGATION_START = 'NavigationTiming navigationStart';

  // This render-process instant event marks the first contentful paint in a
  // main frame.
  var FIRST_CONTENTFUL_PAINT_TITLE = 'firstContentfulPaint';

  function findLoadExpectations(modelHelper) {
    var events = [];
    for (var event of modelHelper.model.getDescendantEvents()) {
      if ((event.title === NAVIGATION_START) ||
          (event.title === FIRST_CONTENTFUL_PAINT_TITLE))
        events.push(event);
    }
    events.sort(tr.importer.compareEvents);

    var loads = [];
    var startEvent = undefined;
    // TODO(alexandermont): What's supposed to happen if there are two
    // NAVIGATION_STARTs with no FIRST_CONTENTFUL_PAINT_TITLE between
    // them? Are you supposed to just "lose" the first NAVIGATION_START,
    // like what's happening now?
    for (var event of events) {
      if (event.title === NAVIGATION_START) {
        startEvent = event;
      } else if (event.title === FIRST_CONTENTFUL_PAINT_TITLE) {
        if (startEvent) {
          loads.push(new tr.model.um.LoadExpectation(
              modelHelper.model, tr.model.um.LOAD_SUBTYPE_NAMES.SUCCESSFUL,
              startEvent.start, event.start - startEvent.start));
          startEvent = undefined;
        }
      }
    }

    // If the trace ended between navigation start and first contentful paint,
    // then make a LoadExpectation that ends at the end of the trace.
    if (startEvent) {
      loads.push(new tr.model.um.LoadExpectation(
            modelHelper.model, tr.model.um.LOAD_SUBTYPE_NAMES.SUCCESSFUL,
            startEvent.start, modelHelper.model.bounds.max - startEvent.start));
    }

    return loads;
  }

  return {
    findLoadExpectations: findLoadExpectations
  };
});
